X-Git-Url: http://git.vanrenterghem.biz/git.ikiwiki.info.git/blobdiff_plain/296e5cb2fd3690e998b3824d54d317933c595873..766311f45b4351488d7dad519a6471094a58da16:/IkiWiki/Plugin/websetup.pm?ds=sidebyside

diff --git a/IkiWiki/Plugin/websetup.pm b/IkiWiki/Plugin/websetup.pm
index 6a5190301..d3cbff0d5 100644
--- a/IkiWiki/Plugin/websetup.pm
+++ b/IkiWiki/Plugin/websetup.pm
@@ -151,7 +151,10 @@ sub showfields ($$$@) {
 		my %info=%{shift @show};
 
 		my $description=$info{description};
-		if (exists $info{link} && length $info{link}) {
+		if (exists $info{htmldescription}) {
+			$description=$info{htmldescription};
+		}
+		elsif (exists $info{link} && length $info{link}) {
 			if ($info{link} =~ /^\w+:\/\//) {
 				$description="<a href=\"$info{link}\">$description</a>";
 			}
@@ -447,22 +450,22 @@ sub showform ($$) {
 			IkiWiki::saveindex();
 			IkiWiki::unlockwiki();
 
 			# Print the top part of a standard misctemplate,
 			# then show the rebuild or refresh, live.
 			my $divider="\0";
-			my $html=IkiWiki::misctemplate("setup", $divider);
+			my $html=IkiWiki::cgitemplate($cgi, "setup", $divider);
 			IkiWiki::printheader($session);
 			my ($head, $tail)=split($divider, $html, 2);
 			print $head."<pre>\n";
 
 			my @command;
 			if ($form->submitted eq 'Rebuild Wiki') {
-				@command=("ikiwiki", "-setup", $config{setupfile},
-                                        "-rebuild", "-v");
+				@command=("ikiwiki", "--setup", $config{setupfile},
+                                        "--rebuild", "-v");
 			}
 			else {
-				@command=("ikiwiki", "-setup", $config{setupfile},
-					"-refresh", "-wrappers", "-v");
+				@command=("ikiwiki", "--setup", $config{setupfile},
+					"--refresh", "--wrappers", "-v");
 			}
 
 			close STDERR;
@@ -447,22 +450,22 @@ sub showform ($$) {
 			IkiWiki::unlockwiki();
 
-			# Print the top part of a standard misctemplate,
+			# Print the top part of a standard cgitemplate,
 			# then show the rebuild or refresh, live.
 			my $divider="\0";